Executor

Struct Executor 

pub struct Executor { /* private fields */ }
An executor interface for Macrosia.

Implementations

Source

impl Executor

pub fn new(context: u8) -> Self

Creates a new, empty execution context.

pub fn set_context(&self, context: u8) -> u8

Sets the context in which this executor is running.

pub fn context(&self) -> u8

Gets the context in which this executor is running.

pub fn get_macro(&self, macro_name: &[u8]) -> Option<&dyn Macro>

Gets a macro from the executor.

pub fn macros( &self, ) -> &HashMap<InternerEntry, Box<dyn Macro>, BuildHasherDefault<SeaHasher>>

Gets the map of all macros in the executor keyed with their names.

pub fn add_macro(&mut self, mac: impl Macro + 'static)

Adds a macro to the executor.

pub fn clear_macros(&mut self)

Adds a macro to the executor.

pub fn evaluate<'slf, 'reg: 'slf, 'buf: 'reg>( &'slf self, string: &'buf [u8], reg: &'reg mut VariableRegistry, step_limit: Option<usize>, debug_log: Option<&mut Vec<String>>, kill: &AtomicBool, ) -> impl FnMut() -> Option<Result<Cow<'buf, [u8]>, MacroError>>

Evaluates a given bytestring, returning it with all macros expanded…

Errors

…or an error if one occurred within one of the expanded macros.

Why is the return like that.

If I had implemented this normally, this function may not terminate immediately - in fact, it may not terminate at all. This returns a function that you can call to iterate one time over what would’ve been a loop. The function will return a None until it is done, and then a Some containing the output value. If you call the function after that, it will simply return a Some(Err(...)).

Think of it like a Coroutine.

Source

impl Executor

pub fn get_builtin(builtin_name: &[u8]) -> Option<&'static dyn Macro>

Does a quick search for a builtin macro, returning None if not found.

pub fn add_stdlib(&mut self)

Adds all standard library macros to the given execution context.

The executor doesn’t actually pull from this for execution anymore, so this is purely for if you need them for e.g. automatically generating documentation.