pub struct VariableRegistry { /* private fields */ }Expand description
A registry to store variables in during macro execution.
Implementations
Sourceimpl VariableRegistry
impl VariableRegistry
Sourcepub fn load<'slf, 'name>(&'slf self, name: InternerEntry) -> Option<&'slf [u8]>
pub fn load<'slf, 'name>(&'slf self, name: InternerEntry) -> Option<&'slf [u8]>
Loads a variable of a given name.
Sourcepub fn load_fn<'slf, 'name>(
&'slf self,
name: InternerEntry,
) -> Option<&'slf ExpressionFunction>
pub fn load_fn<'slf, 'name>( &'slf self, name: InternerEntry, ) -> Option<&'slf ExpressionFunction>
Loads a function of a given name.
Sourcepub fn load_mut<'slf, 'name>(
&'slf mut self,
name: InternerEntry,
) -> Option<&'slf mut [u8]>
pub fn load_mut<'slf, 'name>( &'slf mut self, name: InternerEntry, ) -> Option<&'slf mut [u8]>
Loads a variable of a given name, giving a mutable reference to it.
Sourcepub fn store<'val, 'slf, 'name>(
&'slf mut self,
name: InternerEntry,
val: Cow<'val, [u8]>,
)
pub fn store<'val, 'slf, 'name>( &'slf mut self, name: InternerEntry, val: Cow<'val, [u8]>, )
Stores a variable into a given name, dropping the old value if it existed.